@@ -1,7 +1,9 @@
 import argparse
 import os
 import re
-from typing import Tuple, Union
+from pathlib import Path
+from typing import Tuple
+from typing import Union
 
 import videoxt.constants as C
 import videoxt.utils as utils
@@ -29,10 +31,10 @@ def positive_int(num: Union[float, int, str]) -> int:
     if value <= 0:
         _raise_error(f"expected positive integer, got {num}")
 
-    return value
+    return int(value)
 
 
-def positive_float(num: Union[float, str]) -> float:
+def positive_float(num: Union[float, int, str]) -> float:
     try:
         value = float(num)
     except ValueError:
@@ -44,16 +46,19 @@ def positive_float(num: Union[float, str]) -> float:
     return value
 
 
-def non_negative_int(num: Union[int, str]) -> int:
+def non_negative_int(num: Union[float, int, str]) -> int:
     try:
-        value = int(num)
+        value = float(num)
     except ValueError:
         _raise_error(f"expected integer, got {num!r}")
 
+    if not value.is_integer():
+        _raise_error(f"expected integer, got {num!r}")
+
     if value < 0:
         _raise_error(f"expected non-negative integer, got {num}")
 
-    return value
+    return int(value)
 
 
 def non_negative_float(num: Union[int, float, str]) -> float:
@@ -68,14 +73,16 @@ def non_negative_float(num: Union[int, float, str]) -> float:
     return value
 
 
-def valid_filepath(filepath: str) -> str:
+def valid_filepath(filepath: Union[str, Path]) -> str:
+    filepath = str(filepath)
     if not os.path.isfile(filepath):
         _raise_error(f"file not found, got {filepath!r}")
 
     return filepath
 
 
-def valid_dir(dir: str) -> str:
+def valid_dir(dir: Union[str, Path]) -> str:
+    dir = str(dir)
     if not os.path.exists(dir):
         _raise_error(f"directory not found, got {dir!r}")
 
@@ -109,7 +116,29 @@ def valid_image_format(image_format: str) -> str:
 
 
 def valid_timestamp(timestamp: str, timestamp_type: str) -> str:
+    """Validates timestamp strings with colons are in the correct format:
+    (HH:MM:SS, H:MM:SS, MM:SS, M:SS, SS, S),
+    then converts to seconds for additional validation.
+
+    Milliseconds are ignored.
+
+    If the timestamp does not include a colon,
+    it is assumed to be a float representing seconds.
+
+    If the timestamp_type is "start",
+    the timestamp as seconds is validated to be a non-negative number.
+
+    If the timestamp_type is "stop",
+    the timestamp as seconds validated to be a positive number.
+    """
+    if timestamp_type not in ("start", "stop"):
+        _raise_error(f"invalid timestamp_type, got {timestamp_type!r}")
+
+    if "." in timestamp:
+        timestamp = timestamp.split(".")[0]
+
     timestamp_as_seconds = None
+
     if ":" in timestamp:
         regex = r"^([0-9]|[0-5][0-9])(:[0-5][0-9]){1,2}$"
         if not bool(re.match(regex, timestamp)):
@@ -125,7 +154,7 @@ def valid_timestamp(timestamp: str, timestamp_type: str) -> str:
         )
     elif timestamp_type == "stop":
         timestamp_as_seconds = (
-            positive_float(float(timestamp))
+            positive_float(timestamp)
             if timestamp_as_seconds is None
             else positive_float(timestamp_as_seconds)
         )
@@ -133,7 +162,7 @@ def valid_timestamp(timestamp: str, timestamp_type: str) -> str:
     return timestamp
 
 
-def valid_resize_value(resize_value: Union[float, str]) -> float:
+def valid_resize_value(resize_value: Union[float, int, str]) -> float:
     """Video resize mutliplier max value of 50 is arbitrary, but is used to prevent
     the user from accidentally resizing output to abnormally large size.
     """
@@ -160,34 +189,41 @@ def valid_dimensions(dimensions: Tuple[int, int]) -> Tuple[int, int]:
     return dimensions
 
 
-def valid_rotate_value(rotate_value: Union[int, str]) -> int:
+def valid_rotate_value(rotate_value: Union[float, int, str]) -> int:
     """Valid rotate values are 0, 90, 180, 270."""
+    if isinstance(rotate_value, float):
+        if not rotate_value.is_integer():
+            _raise_error(
+                f"invalid float rotate value, got {rotate_value}\n"
+                f"valid rotate values: {C.VALID_ROTATE_VALUES}"
+            )
+
     try:
-        rotate_value = int(rotate_value)
+        rotate_value = float(rotate_value)
     except ValueError:
         _raise_error(
-            f"invalid rotate value, got {rotate_value!r}\n"
+            f"invalid rotate value, got {rotate_value}\n"
             f"valid rotate values: {C.VALID_ROTATE_VALUES}"
         )
 
     if rotate_value not in C.VALID_ROTATE_VALUES:
         _raise_error(
-            f"invalid rotate value, got {rotate_value!r}\n"
+            f"invalid rotate value, got {rotate_value}\n"
             f"valid rotate values: {C.VALID_ROTATE_VALUES}"
         )
 
-    return rotate_value
+    return int(rotate_value)
 
 
 def valid_start_time(start_time: Union[float, int, str]) -> Union[float, int, str]:
-    if isinstance(start_time, int):
-        start_time = non_negative_int(start_time)
-        return start_time
-
     if isinstance(start_time, float):
         start_time = non_negative_float(start_time)
         return start_time
 
+    if isinstance(start_time, int):
+        start_time = non_negative_int(start_time)
+        return start_time
+
     if isinstance(start_time, str):
         start_time = valid_timestamp(start_time, timestamp_type="start")
         return start_time
@@ -196,14 +232,14 @@ def valid_start_time(start_time: Union[float, int, str]) -> Union[float, int, st
 
 
 def valid_stop_time(stop_time: Union[float, int, str]) -> Union[float, int, str]:
-    if isinstance(stop_time, int):
-        stop_time = positive_int(stop_time)
-        return stop_time
-
     if isinstance(stop_time, float):
         stop_time = positive_float(stop_time)
         return stop_time
 
+    if isinstance(stop_time, int):
+        stop_time = positive_int(stop_time)
+        return stop_time
+
     if isinstance(stop_time, str):
         stop_time = valid_timestamp(stop_time, timestamp_type="stop")
         return stop_time
@@ -225,7 +261,7 @@ def validate_video_extraction_range(
         )
 
 
-def valid_capture_rate(capture_rate: int, start_frame: float, stop_frame: float) -> int:
+def valid_capture_rate(capture_rate: int, start_frame: int, stop_frame: int) -> int:
     """Capture rate is validated after determining the start and stop video frames."""
     if capture_rate > (stop_frame - start_frame):
         _raise_error(
